@@ -16,10 +16,9 @@ Usage::
     session_client: KinesisAnalyticsClient = session.client("kinesisanalytics")
     ```
 """
-from mypy_boto3_kinesisanalytics.client import (
-    KinesisAnalyticsClient,
-    KinesisAnalyticsClient as Client,
-)
+from mypy_boto3_kinesisanalytics.client import KinesisAnalyticsClient
+
+Client = KinesisAnalyticsClient
 
 
 __all__ = ("Client", "KinesisAnalyticsClient")
